@@ -11,19 +11,20 @@ use strict;
 use warnings;
 sub DEBUG(){0};
 use Carp;
-our $VERSION = '0.09';
+our $VERSION = '0.11';
 =head1 VERSION
 
 This document describes version 0.09 of Macrame, released
 April 24, 2009.  Both of Slaven Rezic's reported bugs have been addressed.
 
+Minor changes towards new strictures at PAUSE have been made for version 0.11.
+
 The next step towards getting Macrame to be everything it could become
 appears to be fixing Filter::Simple, by either fixing Filter::Simple so
 it works better, or by replacing it entirely with a more complex tokenizer,
 perhaps L<Filter::PPI>.
 
 
-
 =head1 SYNOPSIS
 
    macro curry OP A1 A2 { (OP A1), curry OP A2 }
@@ -551,7 +552,7 @@ sub deep_fill($$) {
 
 the predefined EXPAND macro takes all tokens up to the next
 semicolon and executes them, inserting the result of the expression
-in the token stream.  The execution takes place in the Macrame::EXPAND
+in the token stream.  The execution takes place in the Macrame::_Expand_
 package space.
 
 =cut
@@ -602,7 +603,7 @@ sub EXPAND_macro {
 #		DEBUG and warn "EXPAND ... FOR topic: list:\n$string\n--";
 #	};
 #        my $in_tree = treeify(<<"EXPANSION");
-#package Macrame::Expand;
+#package Macrame::_Expand_;
 #{
 #   $string
 #}
@@ -612,7 +613,7 @@ sub EXPAND_macro {
 #		my $tstring = $expanded->Stringify;
 #		my $rstring = join "\n", eval $tstring;
 		my $rstring = eval <<EXPANDME;
-package Macrame::Expand;
+package Macrame::_Expand_;
 $string
 EXPANDME
                 $@ and $root->ldie(<<GRIPE);
@@ -872,12 +873,12 @@ sub treeify($) {
                    |
                #             $Filter::Simple::placeholder
 	       #  f::s::ph unacceptably captures its 32-bit counter
-	                     \Q$;\E\C{4}\Q$;\E
+	                     \Q$;\E.{4}\Q$;\E
                    |
                             [,;$@%(){}\[\]]
                    )
  
-         /x, $source
+         /xm, $source
     ];
     # DEBUG and $return_tree->DumpToStderr;
     $return_tree;
@@ -939,7 +940,7 @@ our $SIGILARG = 0;
 
     elsif ( $text =~ /^$Filter::Simple::placeholder$/o ) {
 	# my $index = $PHcounter++;
-	my ($phno) = ($text =~ /\Q$;\E(\C{4})\Q$;\E/) or die
+	my ($phno) = ($text =~ /\Q$;\E(.{4})\Q$;\E/m) or die
              "Check Filter::Simple syntax at version $Filter::Simple::VERSION" ;
 	# $this->text = $index;
 	# $quotelikes[$index] =
@@ -1291,6 +1292,7 @@ sub string {
  #  however we may need this for EXPAND operations
  #   $string =~
  #     s/\Q$;\E(\C{4})\Q$;\E/${$Filter::Simple::components[unpack('N',$1)]}/;
+ # when \C became a syntax error, f::s switched to . instead.
     $string;
 }
 
